@@ -208,10 +208,13 @@ class Client(contacts.Person, BeIdCardHolder, UserAuthored,
                                 verbose_name=format_lazy(u"{}{}",
                                     _("Nationality"), " (2)"))
 
-
     def __str__(self):
-        return "%s %s (%s)" % (
-            self.last_name.upper(), self.first_name, self.pk)
+        info = str(self.pk)
+        u = self.user
+        if u is not None:
+            # info = (str(u.initials or u) + " " + info).strip()
+            info += "/" + str(u.initials or u.username)
+        return "%s %s (%s)" % (self.last_name.upper(), self.first_name, info)
 
     def get_choices_text(self, ar, actor, field):
         if ar:
@@ -242,10 +245,28 @@ class Client(contacts.Person, BeIdCardHolder, UserAuthored,
         owned.project = self
         super(Client, self).update_owned_instance(owned)
 
-    # def full_clean(self, *args, **kw):
-    #     if self.national_id:
-    #         ssin.ssin_validator(self.national_id)
-    #     super(Client, self).full_clean(*args, **kw)
+    def full_clean(self, *args, **kw):
+        prefix = "IP"
+        num_width = 4
+        if self.ref and self.ref.upper().startswith(prefix):
+            num_root = self.ref[len(prefix):].strip()
+            if len(num_root) == num_width:
+                ref_num = num_root
+            else:
+                qs = self.__class__.objects.filter(
+                    ref__startswith="{} {}".format(prefix, num_root)).order_by("ref")
+                qs = qs.exclude(id=self.id)
+                obj = qs.last()
+                if obj is None:
+                    last_ref = num_root.ljust(num_width, "0")
+                else:
+                    last_ref = obj.ref[len(prefix):].strip()
+                ref_num = str(int(last_ref)+1)
+            self.ref = "{} {}".format(prefix, ref_num)
+
+        # if self.national_id:
+        #     ssin.ssin_validator(self.national_id)
+        super(Client, self).full_clean(*args, **kw)
 
     def properties_list(self, *prop_ids):
         """Yields a list of the :class:`PersonProperty
@@ -279,7 +300,6 @@ class Client(contacts.Person, BeIdCardHolder, UserAuthored,
         # if pc:
         #     return pc.end_date
 
-
     def get_dupable_words(self, s):
         s = strip_name_prefix(s)
         return super(Client, self).get_dupable_words(s)
@@ -370,7 +390,7 @@ class ClientDetail(dd.DetailLayout):
     nationality:15 nationality2:15 birth_country birth_place in_belgium_since in_region_since
     card_type #card_number card_issuer card_valid_from card_valid_until
     needs_work_permit has_contact_pcsw has_contact_work_office
-    clients.ContactsByClient uploads.UploadsByClient excerpts.ExcerptsByProject:30
+    clients.ContactsByClient uploads.UploadsByProject excerpts.ExcerptsByProject:30
     """, label=_("Person"))
 
     courses_tab = dd.Panel("""
@@ -459,7 +479,7 @@ class Clients(contacts.Persons):
     required_roles = dd.login_required(ClientsUser)
 
     column_names = "name_column:20 client_state national_id:10 \
-    gsm:10 address_column age:10 email phone:10 id language:10 *"
+    gsm:10 address_column age:10 email phone:10 id ref:8 #language:10 *"
 
     detail_layout = 'avanti.ClientDetail'
 
