@@ -19,7 +19,7 @@ class Plugin(Plugin):
     def setup_main_menu(self, site, user_type, main):
         super(Plugin, self).setup_main_menu(site, user_type, main)
         m = main.add_menu(self.app_label, self.verbose_name)
-        m.add_action('courses.CoursesPlanning')
+        m.add_action('courses.ActivityPlanning')
         m.add_action('courses.DitchingEnrolments')
 
     def setup_explorer_menu(self, site, user_type, main):
